==> tencentcloud-sdk-java-3.1.86-sources.jar: com/tencentcloudapi/solar/v20181011/models/DescribeResourceTemplateHeadersResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.solar.v20181011.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeResourceTemplateHeadersResponse extends AbstractModel{

    /**
    * 记录条数
    */
    @SerializedName("TotalCount")
    @Expose
    private Long TotalCount;

    /**
    * 模板列表
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("TmplList")
    @Expose
    private ResourceTemplateHeader [] TmplList;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 记录条数 
     * @return TotalCount 记录条数
     */
    public Long getTotalCount() {
        return this.TotalCount;
    }

    /**
     * Set 记录条数
     * @param TotalCount 记录条数
     */
    public void setTotalCount(Long TotalCount) {
        this.TotalCount = TotalCount;
    }

    /**
     * Get 模板列表
注意：此字段可能返回 null，表示取不到有效值。 
     * @return TmplList 模板列表
注意：此字段可能返回 null，表示取不到有效值。
     */
    public ResourceTemplateHeader [] getTmplList() {
        return this.TmplList;
    }

    /**
     * Set 模板列表
注意：此字段可能返回 null，表示取不到有效值。
     * @param TmplList 模板列表
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setTmplList(ResourceTemplateHeader [] TmplList) {
        this.TmplList = TmplList;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "TotalCount", this.TotalCount);
        this.setParamArrayObj(map, prefix + "TmplList.", this.TmplList);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.874-sources.jar: com/tencentcloudapi/solar/v20181011/models/DescribeResourceTemplateHeadersResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.solar.v20181011.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeResourceTemplateHeadersResponse extends AbstractModel{

    /**
    * 记录条数
    */
    @SerializedName("TotalCount")
    @Expose
    private Long TotalCount;

    /**
    * 模板列表
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("TmplList")
    @Expose
    private ResourceTemplateHeader [] TmplList;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 记录条数 
     * @return TotalCount 记录条数
     */
    public Long getTotalCount() {
        return this.TotalCount;
    }

    /**
     * Set 记录条数
     * @param TotalCount 记录条数
     */
    public void setTotalCount(Long TotalCount) {
        this.TotalCount = TotalCount;
    }

    /**
     * Get 模板列表
注意：此字段可能返回 null，表示取不到有效值。 
     * @return TmplList 模板列表
注意：此字段可能返回 null，表示取不到有效值。
     */
    public ResourceTemplateHeader [] getTmplList() {
        return this.TmplList;
    }

    /**
     * Set 模板列表
注意：此字段可能返回 null，表示取不到有效值。
     * @param TmplList 模板列表
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setTmplList(ResourceTemplateHeader [] TmplList) {
        this.TmplList = TmplList;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public DescribeResourceTemplateHeadersResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeResourceTemplateHeadersResponse(DescribeResourceTemplateHeadersResponse source) {
        if (source.TotalCount != null) {
            this.TotalCount = new Long(source.TotalCount);
        }
        if (source.TmplList != null) {
            this.TmplList = new ResourceTemplateHeader[source.TmplList.length];
            for (int i = 0; i < source.TmplList.length; i++) {
                this.TmplList[i] = new ResourceTemplateHeader(source.TmplList[i]);
            }
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "TotalCount", this.TotalCount);
        this.setParamArrayObj(map, prefix + "TmplList.", this.TmplList);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
